==> mx-datetime_23.7.04mx23.tar.xz: BUILD/translations/mx-datetime_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="664"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Datum in ura</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="94"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="115"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Datum &amp;&amp; ura</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="181"/>
        <source>H:mm:ss</source>
        <translation>U:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="265"/>
        <location filename="../datetime.cpp" line="318"/>
        <location filename="../datetime.cpp" line="325"/>
        <source>Hardware Clock</source>
        <translation>Strojna ura</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="271"/>
        <source>Hardware Clock tools</source>
        <translation>Ordoja strojne ure</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="277"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Pridobi informacije od strojne ure in jih prikaže v spodnjem okvirju.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="280"/>
        <source>Read the Hardware Clock</source>
        <translation>Odčitaj strojno uro</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Sistemetične popravi odstopanja strojne ure.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Drift Adjust</source>
        <translation>Nastavljanje odstopanja</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="316"/>
        <source>Time transfer</source>
        <translation>Prenos časa</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="322"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Nemudoma nastavi sistemsko uro, da ustreza času, kot ga trenutno kaže strojna ura.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="325"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Strojna ura v sistemsko uro</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Nemudoma nastavi strojno uro, da ustreza času, kot ga trenutno kaže sistemska ura.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Sistemska ura v strojno uro</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Posodobi faktor odstopanja za strojno uro, potem ko je nastavljen.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>Update the drift</source>
        <translation>Posodobi ostopanje</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Časovni pas za strojno uro</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="367"/>
        <source>Local time</source>
        <translation>Lokalni čas</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="370"/>
        <source>Local</source>
        <translation>Lokalno</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="377"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Univerzalni koordinirani čas (ali Greenwiški srednji čas)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="408"/>
        <source>Network Time</source>
        <translation>Omrežni čas</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="414"/>
        <source>Move the selected item down</source>
        <translation>Premakni izbrani element navzdol</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="424"/>
        <source>Move the selected item up</source>
        <translation>Premakni izbrani element navzgor</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="434"/>
        <source>Remove the current item from the list</source>
        <translation>Odstrani trenutni element iz seznama</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="445"/>
        <source>Add an item to the list</source>
        <translation>Dodaj element na seznam</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="465"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Samodejno posodobi sistemsko uro preko NTP strežnikov:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="472"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Nemudoma posodobi sistemsko uro preko NTP strežnikov.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="475"/>
        <source>Update Now</source>
        <translation>Posodobi zdaj</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="487"/>
        <source>List of NTP servers to use.</source>
        <translation>Seznam uporabljenih NTP strežnikov.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="503"/>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="508"/>
        <source>Address</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="513"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="292"/>
        <source>Reading...</source>
        <translation>Odčitavanje...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="306"/>
        <source>Adjusting...</source>
        <translation>Nastavljanje...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="318"/>
        <location filename="../datetime.cpp" line="325"/>
        <source>System Clock</source>
        <translation>Sistemska ura</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="331"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>Čas %1 je bil prenešen v %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="334"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>Časa %1 ni bilo mogoče prenesti v %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="670"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation type="vanished">Posodabljanje...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="382"/>
        <source>The system clock was updated successfully.</source>
        <translation>Sistemska ura je bila uspešno posodobljena.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="385"/>
        <source>The system clock could not be updated.</source>
        <translation>Sistemske ure ni bilo mogoče posodobiti.</translation>
    </message>
    <message>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation type="vanished">Noben od NTP strežnikov iz seznama trenutno ni vklopljen.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="664"/>
        <source>About MX Date &amp; Time</source>
        <translation>O programu MX datum in ura</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="665"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="666"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Grafični program za nastavljanje ure in datuma v MX Linuxu</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="668"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenca</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Dnevnik sprememb</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Prekliči</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="674"/>
        <source>MX Date &amp; Time Help</source>
        <translation>Pomoč za MX datum in ura</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="61"/>
        <source>Changelog</source>
        <translation type="unfinished">Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zapri</translation>
    </message>
</context>
</TS>

==> mx-datetime_24.4mx23.tar.xz: BUILD/translations/mx-datetime_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="754"/>
        <source>MX Date &amp; Time</source>
        <translation>MX datum in ura</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="71"/>
        <source>Apply</source>
        <translation>Uveljavi</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="91"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="111"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Datum &amp;&amp; ura</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="177"/>
        <source>H:mm:ss</source>
        <translation>U:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="261"/>
        <location filename="../datetime.cpp" line="365"/>
        <location filename="../datetime.cpp" line="372"/>
        <source>Hardware Clock</source>
        <translation>Strojna ura</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="267"/>
        <source>Hardware Clock tools</source>
        <translation>Ordoja strojne ure</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="273"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Pridobi informacije od strojne ure in jih prikaže v spodnjem okvirju.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="276"/>
        <source>Read the Hardware Clock</source>
        <translation>Odčitaj strojno uro</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="286"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Sistemetične popravi odstopanja strojne ure.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="289"/>
        <source>Drift Adjust</source>
        <translation>Nastavljanje odstopanja</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="312"/>
        <source>Time transfer</source>
        <translation>Prenos časa</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="318"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Nemudoma nastavi sistemsko uro, da ustreza času, kot ga trenutno kaže strojna ura.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="321"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Strojna ura v sistemsko uro</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="331"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Nemudoma nastavi strojno uro, da ustreza času, kot ga trenutno kaže sistemska ura.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="334"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Sistemska ura v strojno uro</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="344"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Posodobi faktor odstopanja za strojno uro, potem ko je nastavljen.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="347"/>
        <source>Update the drift</source>
        <translation>Posodobi ostopanje</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="357"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Časovni pas za strojno uro</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="363"/>
        <source>Local time</source>
        <translation>Lokalni čas</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="366"/>
        <source>Local</source>
        <translation>Lokalno</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="373"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Univerzalni koordinirani čas (ali Greenwiški srednji čas)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="376"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="404"/>
        <source>Network Time</source>
        <translation>Omrežni čas</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="501"/>
        <source>Move the selected item down</source>
        <translation>Premakni izbrani element navzdol</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="444"/>
        <source>Move the selected item up</source>
        <translation>Premakni izbrani element navzgor</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="434"/>
        <source>Remove the current item from the list</source>
        <translation>Odstrani trenutni element iz seznama</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="410"/>
        <source>Add an item to the list</source>
        <translation>Dodaj element na seznam</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="420"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Samodejno posodobi sistemsko uro preko NTP strežnikov:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="488"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Nemudoma posodobi sistemsko uro preko NTP strežnikov.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="491"/>
        <source>Update Now</source>
        <translation>Posodobi zdaj</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="454"/>
        <source>List of NTP servers to use.</source>
        <translation>Seznam uporabljenih NTP strežnikov.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="470"/>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="475"/>
        <source>Address</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="480"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="334"/>
        <source>Reading...</source>
        <translation>Odčitavanje...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="351"/>
        <source>Adjusting...</source>
        <translation>Nastavljanje...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="365"/>
        <location filename="../datetime.cpp" line="372"/>
        <source>System Clock</source>
        <translation>Sistemska ura</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="378"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>Čas %1 je bil prenešen v %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="381"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>Časa %1 ni bilo mogoče prenesti v %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="760"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation type="vanished">Posodabljanje...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="435"/>
        <source>The system clock was updated successfully.</source>
        <translation>Sistemska ura je bila uspešno posodobljena.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="438"/>
        <source>The system clock could not be updated.</source>
        <translation>Sistemske ure ni bilo mogoče posodobiti.</translation>
    </message>
    <message>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation type="vanished">Noben od NTP strežnikov iz seznama trenutno ni vklopljen.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="753"/>
        <source>About MX Date &amp; Time</source>
        <translation>O programu MX datum in ura</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="755"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="756"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Grafični program za nastavljanje ure in datuma v MX Linuxu</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="759"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Avtorska zaščita (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenca</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Dnevnik sprememb</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Prekliči</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="764"/>
        <source>MX Date &amp; Time Help</source>
        <translation>Pomoč za MX datum in ura</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="61"/>
        <source>Changelog</source>
        <translation type="unfinished">Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zapri</translation>
    </message>
</context>
</TS>
